@@ -16,13 +16,13 @@ def decode(raw):
     try:
         click.echo(
             json.dumps(
-                decode_transaction_raw(tx_raw=raw),
+                decode_transaction_raw(transaction_raw=raw),
                 indent=4
             )
         )
     except UnicodeDecodeError:
         click.echo(click.style("Error: {}")
-                   .format("invalid bytom transaction raw"), err=True)
+                   .format("invalid Bytom transaction raw"), err=True)
         sys.exit()
     except Exception as exception:
         click.echo(click.style("Error: {}")
