@@ -24,34 +24,34 @@ headers.setdefault("Content-Type", "application/json")
 bitcoin = bitcoin()
 
 
-def decode_transaction_raw(tx_raw):
+def decode_transaction_raw(transaction_raw):
     """
-    Decode bitcoin transaction raw.
+    Decode Bitcoin transaction raw.
 
-    :param tx_raw: bitcoin transaction raw.
-    :type tx_raw: str
-    :returns: dict -- decoded bitcoin transaction.
+    :param transaction_raw: Bitcoin transaction raw.
+    :type transaction_raw: str
+    :returns: dict -- decoded Bitcoin transaction.
 
     >>> from shuttle.providers.bitcoin.utils import decode_transaction_raw
     >>> decode_transaction_raw(transaction_raw)
     {...}
     """
 
-    tx_raw = str(tx_raw + "=" * (-len(tx_raw) % 4))
+    transaction_raw = str(transaction_raw + "=" * (-len(transaction_raw) % 4))
     try:
-        tx_raw = json.loads(b64decode(str(tx_raw).encode()).decode())
+        decoded_transaction_raw = json.loads(b64decode(str(transaction_raw).encode()).decode())
     except (binascii.Error, json.decoder.JSONDecodeError) as _error:
-        raise ValueError("invalid bitcoin transaction raw")
-    if "type" not in tx_raw or not str(tx_raw["type"]).startswith("bitcoin"):
-        raise ValueError("invalid bitcoin transaction raw")
+        raise ValueError("invalid Bitcoin transaction raw")
+    if "type" not in decoded_transaction_raw or not str(decoded_transaction_raw["type"]).startswith("bitcoin"):
+        raise ValueError("invalid Bitcoin transaction raw")
     # Setting testnet
-    stp(tx_raw["network"], strict=True)
-    tx = MutableTransaction.unhexlify(tx_raw["raw"])
+    stp(decoded_transaction_raw["network"], strict=True)
+    tx = MutableTransaction.unhexlify(decoded_transaction_raw["raw"])
     return dict(
-        fee=tx_raw["fee"],
-        type=tx_raw["type"],
+        fee=decoded_transaction_raw["fee"],
+        type=decoded_transaction_raw["type"],
         tx=tx.to_json(),
-        network=tx_raw["network"]
+        network=decoded_transaction_raw["network"]
     )
 
 
@@ -67,27 +67,27 @@ def submit_payment(tx_raw, network="testnet", timeout=bitcoin["timeout"]):
     raise TypeError("transaction raw must be string format!")
 
 
-def submit_transaction_raw(tx_raw):
+def submit_transaction_raw(transaction_raw):
     """
     Submit transaction raw to Bitcoin blockchain.
 
-    :param tx_raw: bitcoin transaction raw.
-    :type tx_raw: str
-    :returns: dict -- bitcoin transaction id, fee, type and date.
+    :param transaction_raw: Bitcoin transaction raw.
+    :type transaction_raw: str
+    :returns: dict -- Bitcoin transaction id, fee, type and date.
 
     >>> from shuttle.providers.bitcoin.utils import submit_transaction_raw
     >>> submit_transaction_raw(transaction_raw)
     {...}
     """
 
-    tx_raw = str(tx_raw + "=" * (-len(tx_raw) % 4))
+    tx_raw = str(transaction_raw + "=" * (-len(transaction_raw) % 4))
     try:
         # Decoding transaction raw.
         decoded_tx_raw = json.loads(b64decode(str(tx_raw).encode()).decode())
     except (binascii.Error, json.decoder.JSONDecodeError) as _error:
-        raise ValueError("invalid bitcoin transaction raw")
+        raise ValueError("invalid Bitcoin transaction raw")
     if "type" not in decoded_tx_raw or not str(decoded_tx_raw["type"]).startswith("bitcoin"):
-        raise ValueError("invalid bitcoin transaction raw")
+        raise ValueError("invalid Bitcoin transaction raw")
     submitted = submit_payment(
         tx_raw=decoded_tx_raw["raw"],
         network=decoded_tx_raw["network"]
@@ -95,7 +95,7 @@ def submit_transaction_raw(tx_raw):
     return dict(
         fee=decoded_tx_raw["fee"],
         type=decoded_tx_raw["type"],
-        tx_id=submitted["txid"],
+        transaction_id=submitted["txid"],
         network=decoded_tx_raw["network"],
         date=str(datetime.datetime.utcnow())
     )
@@ -104,13 +104,13 @@ def submit_transaction_raw(tx_raw):
 # Checking address
 def is_address(address, network=None):
     """
-    Check bitcoin address.
+    Check Bitcoin address.
 
-    :param address: bitcoin address.
+    :param address: Bitcoin address.
     :type address: str
-    :param network: bitcoin network, defaults to testnet.
+    :param network: Bitcoin network, defaults to testnet.
     :type network: str
-    :returns: bool -- bitcoin valid/invalid address.
+    :returns: bool -- Bitcoin valid/invalid address.
 
     >>> from shuttle.providers.bitcoin.utils import is_address
     >>> is_address(bitcoin_address, "testnet")
@@ -181,7 +181,7 @@ def fee_calculator(transaction_input=1, transaction_output=1):
     :type transaction_input: int
     :param transaction_output: transaction output numbers, defaults to 1.
     :type transaction_output: int
-    :returns: int -- bitcoin fee.
+    :returns: int -- Bitcoin fee.
 
     >>> from shuttle.providers.bitcoin.utils import fee_calculator
     >>> fee_calculator(2, 9)
@@ -209,11 +209,11 @@ def script_from_address(address, network="testnet"):
     """
     Get script from address.
 
-    :param address: bitcoin address.
+    :param address: Bitcoin address.
     :type address: str
-    :param network: bitcoin network, defaults to testnet.
+    :param network: Bitcoin network, defaults to testnet.
     :type network: str
-    :returns: P2pkhScript, P2shScript -- bitcoin p2pkh or p2sh script instance.
+    :returns: P2pkhScript, P2shScript -- Bitcoin p2pkh or p2sh script instance.
 
     >>> from shuttle.providers.bitcoin.utils import script_from_address
     >>> script_from_address("mrmtGq2HMmqAogSsGDjCtXUpxrb7rHThFH", "testnet")
@@ -235,11 +235,11 @@ def address_to_hash(address, network="testnet"):
     """
     Get hash from address.
 
-    :param address: bitcoin address.
+    :param address: Bitcoin address.
     :type address: str
-    :param network: bitcoin network, defaults to testnet.
+    :param network: Bitcoin network, defaults to testnet.
     :type network: str
-    :returns: P2pkhScript, P2shScript -- bitcoin p2pkh or p2sh script instance.
+    :returns: P2pkhScript, P2shScript -- Bitcoin p2pkh or p2sh script instance.
 
     >>> from shuttle.providers.bitcoin.utils import address_to_hash
     >>> address_to_hash("mrmtGq2HMmqAogSsGDjCtXUpxrb7rHThFH", "testnet")
